@@ -51,14 +51,22 @@ void Controller::setMediaPlayer(const QString &player) {
     mediaPlayer = player.toLower().replace(" ", "");
 }
 
+bool Controller::kmPlayerInstalled() {
+    bool isInstalled = false;
+    if ((QFile::exists("/opt/kmplayer/bin/kmplayer")) || (QFile::exists("/usr/bin/kmplayer"))) {
+        isInstalled = true;
+    }
+    return isInstalled;
+}
+
 void Controller::playVideo(const QString &url) {
-    #ifdef Q_WS_MAEMO_5
-//    qDebug() << url;
+#ifdef Q_WS_MAEMO_5
+    //    qDebug() << url;
     minimize();
     QDBusConnection bus = QDBusConnection::sessionBus();
     QDBusInterface dbus_iface("com.nokia." + mediaPlayer, "/com/nokia/" + mediaPlayer, "com.nokia." + mediaPlayer, bus);
     dbus_iface.call("mime_open", url);
-    #endif
+#endif
 }
 
 void Controller::deleteVideo(const QString &path) {
